@@ -3,7 +3,7 @@ $(TYPEDEF)
 
 Holds a tableau which defines an explicit Runge-Kutta method.
 """
-mutable struct ExplicitRKTableau{MType <: AbstractMatrix, VType <: AbstractVector, S} <:
+mutable struct ExplicitRKTableau{MType <: AbstractMatrix, VType <: AbstractVector, S, IType} <:
                ODERKTableau
     A::MType
     c::VType
@@ -15,14 +15,15 @@ mutable struct ExplicitRKTableau{MType <: AbstractMatrix, VType <: AbstractVecto
     adaptiveorder::Int #The lower order of the pair. Only used for adaptivity.
     fsal::Bool
     stability_size::S
+    B_interp::IType
 end
 function ExplicitRKTableau(A::MType, c::VType, α::VType, order;
         adaptiveorder = 0, αEEst = similar(α, 0),
         fsal = false, stability_size = 0.0,
-        d = similar(α, 0)) where {MType, VType}
+        d = similar(α, 0), B_interp::IType = nothing) where {MType, VType, IType}
     S = typeof(stability_size)
-    ExplicitRKTableau{MType, VType, S}(A, c, α, αEEst, d, length(α), order, adaptiveorder,
-        fsal, stability_size)
+    ExplicitRKTableau{MType, VType, S, IType}(A, c, α, αEEst, d, length(α), order, adaptiveorder,
+        fsal, stability_size, B_interp)
 end
 
 """
